==> distribution-5.52.1.zip: drr/regulation/techsprint/g20/mas/reports/InterestRateResetFrequencyPeriodLeg1Rule.java <==
package drr.regulation.techsprint.g20.mas.reports;

import cdm.base.datetime.CalculationPeriodFrequency;
import cdm.base.datetime.PeriodExtendedEnum;
import cdm.product.asset.FixedRateSpecification;
import cdm.product.asset.InterestRatePayout;
import cdm.product.asset.RateSpecification;
import cdm.product.common.schedule.CalculationPeriodDates;
import com.google.inject.ImplementedBy;
import com.rosetta.model.lib.mapper.MapperS;
import com.rosetta.model.lib.reports.ReportFunction;
import drr.regulation.common.TransactionReportInstruction;
import javax.inject.Inject;

import static com.rosetta.model.lib.expression.ExpressionOperators.*;

@ImplementedBy(InterestRateResetFrequencyPeriodLeg1Rule.InterestRateResetFrequencyPeriodLeg1RuleDefault.class)
public abstract class InterestRateResetFrequencyPeriodLeg1Rule implements ReportFunction<TransactionReportInstruction, PeriodExtendedEnum> {
	
	// RosettaFunction dependencies
	//
	@Inject protected FixedFloatLeg1Rule fixedFloatLeg1Rule;
	@Inject protected IsInterestRatePayoutRule isInterestRatePayoutRule;

	/**
	* @param input 
	* @return output 
	*/
	@Override
	public PeriodExtendedEnum evaluate(TransactionReportInstruction input) {
		PeriodExtendedEnum output = doEvaluate(input);
		
		return output;
	}

	protected abstract PeriodExtendedEnum doEvaluate(TransactionReportInstruction input);

	public static class InterestRateResetFrequencyPeriodLeg1RuleDefault extends InterestRateResetFrequencyPeriodLeg1Rule {
		@Override
		protected PeriodExtendedEnum doEvaluate(TransactionReportInstruction input) {
			PeriodExtendedEnum output = null;
			return assignOutput(output, input);
		}
		
		protected PeriodExtendedEnum assignOutput(PeriodExtendedEnum output, TransactionReportInstruction input) {
			final MapperS<TransactionReportInstruction> thenArg0 = MapperS.of(input)
				.filterSingleNullSafe(item -> isInterestRatePayoutRule.evaluate(item.get()));
			final MapperS<InterestRatePayout> thenArg1 = thenArg0
				.mapSingleToItem(item -> MapperS.of(fixedFloatLeg1Rule.evaluate(item.get())));
			final MapperS<InterestRatePayout> thenArg2 = thenArg1
				.filterSingleNullSafe(item -> exists(item.<RateSpecification>map("getRateSpecification", interestRatePayout -> interestRatePayout.getRateSpecification()).<FixedRateSpecification>map("getFixedRate", rateSpecification -> rateSpecification.getFixedRate())).get());
			output = thenArg2
				.mapSingleToItem(item -> item.<CalculationPeriodDates>map("getCalculationPeriodDates", interestRatePayout -> interestRatePayout.getCalculationPeriodDates()).<CalculationPeriodFrequency>map("getCalculationPeriodFrequency", calculationPeriodDates -> calculationPeriodDates.getCalculationPeriodFrequency()).<PeriodExtendedEnum>map("getPeriod", calculationPeriodFrequency -> calculationPeriodFrequency.getPeriod())).get();
			
			return output;
		}
	}
}

==> distribution-5.57.0.zip: drr/regulation/techsprint/g20/mas/reports/InterestRateResetFrequencyPeriodLeg1Rule.java <==
package drr.regulation.techsprint.g20.mas.reports;

import cdm.base.datetime.CalculationPeriodFrequency;
import cdm.base.datetime.PeriodExtendedEnum;
import cdm.product.asset.FixedRateSpecification;
import cdm.product.asset.InterestRatePayout;
import cdm.product.asset.RateSpecification;
import cdm.product.common.schedule.CalculationPeriodDates;
import com.google.inject.ImplementedBy;
import com.rosetta.model.lib.mapper.MapperS;
import com.rosetta.model.lib.reports.ReportFunction;
import drr.regulation.common.TransactionReportInstruction;
import javax.inject.Inject;

import static com.rosetta.model.lib.expression.ExpressionOperatorsNullSafe.*;

@ImplementedBy(InterestRateResetFrequencyPeriodLeg1Rule.InterestRateResetFrequencyPeriodLeg1RuleDefault.class)
public abstract class InterestRateResetFrequencyPeriodLeg1Rule implements ReportFunction<TransactionReportInstruction, PeriodExtendedEnum> {
	
	// RosettaFunction dependencies
	//
	@Inject protected FixedFloatLeg1Rule fixedFloatLeg1Rule;
	@Inject protected IsInterestRatePayoutRule isInterestRatePayoutRule;

	/**
	* @param input 
	* @return output 
	*/
	@Override
	public PeriodExtendedEnum evaluate(TransactionReportInstruction input) {
		PeriodExtendedEnum output = doEvaluate(input);
		
		return output;
	}

	protected abstract PeriodExtendedEnum doEvaluate(TransactionReportInstruction input);

	public static class InterestRateResetFrequencyPeriodLeg1RuleDefault extends InterestRateResetFrequencyPeriodLeg1Rule {
		@Override
		protected PeriodExtendedEnum doEvaluate(TransactionReportInstruction input) {
			PeriodExtendedEnum output = null;
			return assignOutput(output, input);
		}
		
		protected PeriodExtendedEnum assignOutput(PeriodExtendedEnum output, TransactionReportInstruction input) {
			final MapperS<TransactionReportInstruction> thenArg0 = MapperS.of(input)
				.filterSingleNullSafe(item -> isInterestRatePayoutRule.evaluate(item.get()));
			final MapperS<InterestRatePayout> thenArg1 = thenArg0
				.mapSingleToItem(item -> MapperS.of(fixedFloatLeg1Rule.evaluate(item.get())));
			final MapperS<InterestRatePayout> thenArg2 = thenArg1
				.filterSingleNullSafe(item -> exists(item.<RateSpecification>map("getRateSpecification", interestRatePayout -> interestRatePayout.getRateSpecification()).<FixedRateSpecification>map("getFixedRate", rateSpecification -> rateSpecification.getFixedRate())).get());
			output = thenArg2
				.mapSingleToItem(item -> item.<CalculationPeriodDates>map("getCalculationPeriodDates", interestRatePayout -> interestRatePayout.getCalculationPeriodDates()).<CalculationPeriodFrequency>map("getCalculationPeriodFrequency", calculationPeriodDates -> calculationPeriodDates.getCalculationPeriodFrequency()).<PeriodExtendedEnum>map("getPeriod", calculationPeriodFrequency -> calculationPeriodFrequency.getPeriod())).get();
			
			return output;
		}
	}
}
